==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/databoxedge/kotlin/inputs/GetDeviceExtendedInformationPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.databoxedge.kotlin.inputs

import com.pulumi.azurenative.databoxedge.inputs.GetDeviceExtendedInformationPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property deviceName The device name.
 * @property resourceGroupName The resource group name.
 */
public data class GetDeviceExtendedInformationPlainArgs(
    public val deviceName: String,
    public val resourceGroupName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.databoxedge.inputs.GetDeviceExtendedInformationPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.databoxedge.inputs.GetDeviceExtendedInformationPlainArgs =
        com.pulumi.azurenative.databoxedge.inputs.GetDeviceExtendedInformationPlainArgs.builder()
            .deviceName(deviceName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetDeviceExtendedInformationPlainArgs].
 */
@PulumiTagMarker
public class GetDeviceExtendedInformationPlainArgsBuilder internal constructor() {
    private var deviceName: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value The device name.
     */
    @JvmName("xtgjbfnluffaceks")
    public suspend fun deviceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.deviceName = mapped
    }

    /**
     * @param value The resource group name.
     */
    @JvmName("sbkgfnpwrybdrovt")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): GetDeviceExtendedInformationPlainArgs =
        GetDeviceExtendedInformationPlainArgs(
            deviceName = deviceName ?: throw PulumiNullFieldException("deviceName"),
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/databoxedge/kotlin/inputs/GetDeviceExtendedInformationPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.databoxedge.kotlin.inputs

import com.pulumi.azurenative.databoxedge.inputs.GetDeviceExtendedInformationPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property deviceName The device name.
 * @property resourceGroupName The resource group name.
 */
public data class GetDeviceExtendedInformationPlainArgs(
    public val deviceName: String,
    public val resourceGroupName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.databoxedge.inputs.GetDeviceExtendedInformationPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.databoxedge.inputs.GetDeviceExtendedInformationPlainArgs =
        com.pulumi.azurenative.databoxedge.inputs.GetDeviceExtendedInformationPlainArgs.builder()
            .deviceName(deviceName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetDeviceExtendedInformationPlainArgs].
 */
@PulumiTagMarker
public class GetDeviceExtendedInformationPlainArgsBuilder internal constructor() {
    private var deviceName: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value The device name.
     */
    @JvmName("vfklubqyxeejeqca")
    public suspend fun deviceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.deviceName = mapped
    }

    /**
     * @param value The resource group name.
     */
    @JvmName("lmarsgdhpfmwmhvo")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): GetDeviceExtendedInformationPlainArgs =
        GetDeviceExtendedInformationPlainArgs(
            deviceName = deviceName ?: throw PulumiNullFieldException("deviceName"),
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        )
}
